@@ -5,8 +5,9 @@
 #' @inheritParams parameters::model_parameters
 #'
 #' @importFrom parameters model_parameters
-#' @importFrom insight standardize_names
-#' @importFrom dplyr select matches
+#' @importFrom parameters standardize_names
+#' @importFrom dplyr select matches rename_all recode contains
+#' @importFrom tidyr fill
 #'
 #' @examples
 #' model <- lm(mpg ~ wt + cyl, data = mtcars)
@@ -16,25 +17,9 @@
 tidy_model_parameters <- function(model, ...) {
   parameters::model_parameters(model, verbose = FALSE, ...) %>%
     dplyr::select(-dplyr::matches("Difference")) %>%
-    parameters::standardize_names(data = ., style = "broom") %>%
-    as_tibble(.)
-}
-
-#' @name tidy_model_performance
-#' @title Convert `performance` package output to `tidyverse` conventions
-#'
-#' @inheritParams performance::model_performance
-#'
-#' @importFrom performance model_performance
-#'
-#' @examples
-#' model <- lm(mpg ~ wt + cyl, data = mtcars)
-#' tidy_model_parameters(model)
-#' @export
-
-tidy_model_performance <- function(model, ...) {
-  performance::model_performance(model, verbose = FALSE, ...) %>%
-    parameters::standardize_names(data = ., style = "broom") %>%
+    parameters::standardize_names(style = "broom") %>%
+    dplyr::rename_all(.funs = dplyr::recode, "bayes.factor" = "bf10") %>%
+    tidyr::fill(dplyr::matches("^prior|^bf"), .direction = "updown") %>%
     as_tibble(.)
 }
 
@@ -54,7 +39,7 @@ tidy_model_performance <- function(model, ...) {
 tidy_model_effectsize <- function(data) {
   data %>%
     dplyr::mutate(effectsize = stats::na.omit(effectsize::get_effectsize_label(colnames(.)))[[1]]) %>%
-    parameters::standardize_names(data = ., style = "broom") %>%
+    parameters::standardize_names(style = "broom") %>%
     dplyr::select(-dplyr::contains("term")) %>%
     as_tibble(.)
 }
